#
# (C) Copyright 2025- ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
#

from grib_check.Assert import Eq, IsIn, IsMultipleOf
from grib_check.Report import Report

from .Uerra import Uerra


class Crra(Uerra):
    def __init__(self, lookup_table, check_limits=False, check_validity=True):
        super().__init__(lookup_table, check_limits=check_limits, check_validity=check_validity)

    def basic_checks_2(self, message, p) -> Report:
        report = Report("Crra Basic Checks")
        report.add(IsIn(message["productionStatusOfProcessedData"], [10, 11]))
        report.add(
            IsIn(message["typeOfProcessedData"], [0, 1])
        )  # 0 = analysis , 1 = forecast
        if message["typeOfProcessedData"] == 0:
            report.add(Eq(message["step"], 0))
        else:
            report.add(
                IsIn(message["step"], [1, 2, 4, 5]) | IsMultipleOf(message["step"], 3)
            )
        return report

    def _pressure_level(self, message, p) -> Report:
        report = Report("Crra Pressure Level")
        levels = [
            1000,
            975,
            950,
            925,
            900,
            875,
            850,
            825,
            800,
            750,
            700,
            600,
            500,
            400,
            300,
            250,
            200,
            150,
            100,
            70,
            50,
            30,
            20,
            10,
            7,
            5,
            3,
            2,
            1,
        ]
        report.add(IsIn(message["level"], levels, "invalid pressure level"))
        return report



#
# (C) Copyright 2025- ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
#

from grib_check.Assert import Fail
from grib_check.checker.Tigge import Tigge
from grib_check.Grib import Grib
from grib_check.Report import Report


def dummy(a, b):
    report = Report()
    report.add(Fail("dummy"))
    return report


class TestTest:
    # def test_create_wmo_test(self):
    #     check_map = {
    #         # "product_definition_template_number": self.__product_definition_template_number,
    #         # "derived_forecast": self.__derived_forecast
    #         "product_definition_template_number": dummy,
    #         "derived_forecast": dummy
    #     }
    #
    #     parameter = {
    #         "pairs": [
    #             {"key": "stream", "value": "eefo"},
    #             {"key": "dataType", "value": "fcmean"}
    #         ],
    #         "expected": [
    #             {"key": "productDefinitionTemplateNumber", "value": 11},
    #             {"key": "paramId", "value": "228004"},
    #             {"key": "shortName", "value": "mean2t"},
    #             {"key": "name", "value": "Mean 2 metre temperature"}
    #         ],
    #         "checks": ["product_definition_template_number"]
    #     }
    #
    #     for message in Grib("dgov-data/od_eefo_taes_sfc_2024_0001_reduced_gg.grib2"):
    #         test = WmoTest(message, parameter, check_map)
    #         test.run()

    def test_create_tigge_test(self):
        check_map = {
            "point_in_time": dummy,
            "given_level": dummy,
        }

        parameter = {
            "name": "10_meter_u_velocity_sfc.glob",
            "min1": -100,
            "min2": -1,
            "max1": 1,
            "max2": 100,
            "pairs": [
                {
                    "key": "model",
                    "key_type": "str",
                    "value_long": 0,
                    "value_string": "glob",
                },
                {"key": "paramId", "key_type": "int", "value_long": 165},
                {"key": "discipline", "key_type": "int", "value_long": 0},
                {"key": "parameterCategory", "key_type": "int", "value_long": 2},
                {"key": "parameterNumber", "key_type": "int", "value_long": 2},
                {
                    "key": "scaleFactorOfFirstFixedSurface",
                    "key_type": "int",
                    "value_long": 0,
                },
                {
                    "key": "scaledValueOfFirstFixedSurface",
                    "key_type": "int",
                    "value_long": 10,
                },
                {
                    "key": "typeOfFirstFixedSurface",
                    "key_type": "int",
                    "value_long": 103,
                },
            ],
            "checks": ["point_in_time", "given_level"],
        }

        for message in Grib("./tests/tigge/tigge_ecmf_sfc_10v.grib"):
            test = Tigge.DefaultTest(message, parameter, check_map)
            test.run()
